# My Library
Biblioteca para facilitar a integração com APIs.  

## Instalação
```bash
pip install my-library


# USO BÁSICO
from my_library.core import fetch_api_data

data = fetch_api_data("https://api.exemplo.com/data")
print(data)

